function [ret,x0,str,ts,xts]=demo(t,x,u,flag);
%DEMO	is the M-file description of the SIMULINK system named DEMO.
%	The block-diagram can be displayed by typing: DEMO.
%
%	SYS=DEMO(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DEMO to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DEMO with a FLAG of zero:
%	[SIZES]=DEMO([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[8,95,898,494])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Euler')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '25.0')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Mux',[sys,'/','Mux2'])
set_param([sys,'/','Mux2'],...
		'hide name',0,...
		'inputs','6',...
		'position',[165,138,200,357])


%     Subsystem  ['Controller',13,'(see initdemo)'].

new_system([sys,'/',['Controller',13,'(see initdemo)']])
set_param([sys,'/',['Controller',13,'(see initdemo)']],'Location',[594,695,996,874])

add_block('built-in/Outport',[sys,'/',['Controller',13,'(see initdemo)/u']])
set_param([sys,'/',['Controller',13,'(see initdemo)/u']],...
		'position',[295,70,315,90])

add_block('built-in/State-Space',[sys,'/',['Controller',13,'(see initdemo)/Controller']])
set_param([sys,'/',['Controller',13,'(see initdemo)/Controller']],...
		'A','Ac',...
		'B','Bc',...
		'C','Cc',...
		'D','Dc',...
		'position',[185,59,260,101])

add_block('built-in/Inport',[sys,'/',['Controller',13,'(see initdemo)/x_d']])
set_param([sys,'/',['Controller',13,'(see initdemo)/x_d']],...
		'Port','2',...
		'position',[80,75,100,95])

add_block('built-in/Inport',[sys,'/',['Controller',13,'(see initdemo)/x']])
set_param([sys,'/',['Controller',13,'(see initdemo)/x']],...
		'move name',0,...
		'position',[80,60,100,80])

add_block('built-in/Mux',[sys,'/',['Controller',13,'(see initdemo)/Mux1']])
set_param([sys,'/',['Controller',13,'(see initdemo)/Mux1']],...
		'hide name',0,...
		'inputs','2',...
		'position',[130,61,160,94])
add_line([sys,'/',['Controller',13,'(see initdemo)']],[105,70;125,70])
add_line([sys,'/',['Controller',13,'(see initdemo)']],[265,80;290,80])
add_line([sys,'/',['Controller',13,'(see initdemo)']],[105,85;125,85])
add_line([sys,'/',['Controller',13,'(see initdemo)']],[165,80;180,80])


%     Finished composite block ['Controller',13,'(see initdemo)'].

set_param([sys,'/',['Controller',13,'(see initdemo)']],...
		'position',[285,127,315,178])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[400,140,420,160])

add_block('built-in/Constant',[sys,'/','VoltM [Volt]'])
set_param([sys,'/','VoltM [Volt]'],...
		'Value','Vm',...
		'position',[130,35,155,55])

add_block('built-in/Constant',[sys,'/','paddle [rad]'])
set_param([sys,'/','paddle [rad]'],...
		'Value','paddle',...
		'position',[25,60,75,80])

add_block('built-in/Constant',[sys,'/','delta_e [rad]'])
set_param([sys,'/','delta_e [rad]'],...
		'Value','delta_e',...
		'position',[125,81,175,99])

add_block('built-in/Mux',[sys,'/','Mux3'])
set_param([sys,'/','Mux3'],...
		'hide name',0,...
		'inputs','3',...
		'position',[320,53,350,87])

add_block('built-in/Constant',[sys,'/','thetadot [rad//s]'])
set_param([sys,'/','thetadot [rad//s]'],...
		'Value','0',...
		'position',[60,325,80,345])

add_block('built-in/Constant',[sys,'/','z [m]'])
set_param([sys,'/','z [m]'],...
		'Value','0',...
		'position',[95,184,130,206])

add_block('built-in/From Workspace',[sys,'/',['x = dotx*time',13,'[m]  from workspace']])
set_param([sys,'/',['x = dotx*time',13,'[m]  from workspace']],...
		'matl_expr','[T, Xtime]',...
		'position',[35,120,95,150])

add_block('built-in/Constant',[sys,'/','theta [rad]'])
set_param([sys,'/','theta [rad]'],...
		'Value','theta',...
		'position',[25,218,80,242])

add_block('built-in/Constant',[sys,'/','xdot [m//s]'])
set_param([sys,'/','xdot [m//s]'],...
		'Value','xdot',...
		'position',[85,255,115,275])

add_block('built-in/Constant',[sys,'/','zdot [m//s]'])
set_param([sys,'/','zdot [m//s]'],...
		'Value','0',...
		'position',[30,290,50,310])

add_block('built-in/S-Function',[sys,'/','Ducted Fan'])
set_param([sys,'/','Ducted Fan'],...
		'function name','fansim',...
		'parameters','state+disturbance',...
		'position',[465,140,540,160])

add_block('built-in/Note',[sys,'/',['demo.m  .......... run initdemo.m first.',13,'Simulation for forward flight stabilization. ']])
set_param([sys,'/',['demo.m  .......... run initdemo.m first.',13,'Simulation for forward flight stabilization. ']],...
		'position',[390,290,395,295])


%     Subsystem  'display'.

new_system([sys,'/','display'])
set_param([sys,'/','display'],'Location',[647,89,1133,515])
open_system([sys,'/','display'])

add_block('built-in/Demux',[sys,'/','display/xd//ud'])
set_param([sys,'/','display/xd//ud'],...
		'outputs','6',...
		'position',[70,126,105,279])

add_block('built-in/Mux',[sys,'/','display/Mux1'])
set_param([sys,'/','display/Mux1'],...
		'hide name',0,...
		'inputs','3',...
		'position',[150,137,175,193])

add_block('built-in/Inport',[sys,'/','display/in_3'])
set_param([sys,'/','display/in_3'],...
		'position',[40,50,60,70])


%     Subsystem  'display/VoltM, paddle, deltae'.

new_system([sys,'/','display/VoltM, paddle, deltae'])
set_param([sys,'/','display/VoltM, paddle, deltae'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','display/VoltM, paddle, deltae/x'])
set_param([sys,'/','display/VoltM, paddle, deltae/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['display/VoltM, paddle, deltae/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['display/VoltM, paddle, deltae/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/','display/VoltM, paddle, deltae'],[90,65;125,65])
set_param([sys,'/','display/VoltM, paddle, deltae'],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/','display/VoltM, paddle, deltae'],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/','display/VoltM, paddle, deltae'],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/','display/VoltM, paddle, deltae'],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/','display/VoltM, paddle, deltae'],...
		'Mask Entries','5\/-10\/10\/2000\/''y-/g--/b-.''\/')


%     Finished composite block 'display/VoltM, paddle, deltae'.

set_param([sys,'/','display/VoltM, paddle, deltae'],...
		'position',[380,40,410,80])

add_block('built-in/Mux',[sys,'/','display/Mux3'])
set_param([sys,'/','display/Mux3'],...
		'hide name',0,...
		'inputs','3',...
		'position',[295,23,325,97])

add_block('built-in/Demux',[sys,'/','display/xd//ud1'])
set_param([sys,'/','display/xd//ud1'],...
		'outputs','3',...
		'position',[95,24,130,96])

add_block('built-in/Gain',[sys,'/','display/Gain'])
set_param([sys,'/','display/Gain'],...
		'Gain','rad2deg',...
		'position',[150,47,225,73])

add_block('built-in/Gain',[sys,'/','display/Gain1'])
set_param([sys,'/','display/Gain1'],...
		'Gain','rad2deg',...
		'position',[200,72,275,98])


%     Subsystem  'display/reference trajectory'.

new_system([sys,'/','display/reference trajectory'])
set_param([sys,'/','display/reference trajectory'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['display/reference trajectory/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['display/reference trajectory/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','display/reference trajectory/x'])
set_param([sys,'/','display/reference trajectory/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','display/reference trajectory'],[90,65;125,65])
set_param([sys,'/','display/reference trajectory'],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/','display/reference trajectory'],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/','display/reference trajectory'],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/','display/reference trajectory'],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/','display/reference trajectory'],...
		'Mask Entries','5\/-10\/10\/2000\/''y-/g--/c-./w:/m*/ro''\/')


%     Finished composite block 'display/reference trajectory'.

set_param([sys,'/','display/reference trajectory'],...
		'position',[115,310,145,350])

add_block('built-in/Inport',[sys,'/','display/in_4'])
set_param([sys,'/','display/in_4'],...
		'Port','3',...
		'position',[30,320,50,340])

add_block('built-in/Mux',[sys,'/','display/Mux2'])
set_param([sys,'/','display/Mux2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[150,211,175,269])


%     Subsystem  'display/x, z, theta'.

new_system([sys,'/','display/x, z, theta'])
set_param([sys,'/','display/x, z, theta'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['display/x, z, theta/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['display/x, z, theta/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','display/x, z, theta/x'])
set_param([sys,'/','display/x, z, theta/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','display/x, z, theta'],[90,65;125,65])
set_param([sys,'/','display/x, z, theta'],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/','display/x, z, theta'],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/','display/x, z, theta'],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/','display/x, z, theta'],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/','display/x, z, theta'],...
		'Mask Entries','5\/-10\/10\/2000\/''y-/g--/b-./w:/m/ro''\/')


%     Finished composite block 'display/x, z, theta'.

set_param([sys,'/','display/x, z, theta'],...
		'position',[210,145,240,185])


%     Subsystem  'display/xdot, zdot, thetadot'.

new_system([sys,'/','display/xdot, zdot, thetadot'])
set_param([sys,'/','display/xdot, zdot, thetadot'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','display/xdot, zdot, thetadot/x'])
set_param([sys,'/','display/xdot, zdot, thetadot/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['display/xdot, zdot, thetadot/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['display/xdot, zdot, thetadot/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/','display/xdot, zdot, thetadot'],[90,65;125,65])
set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'Mask Entries','5\/-10\/10\/2000\/''y-/g--/b-./w:/m/ro''\/')


%     Finished composite block 'display/xdot, zdot, thetadot'.

set_param([sys,'/','display/xdot, zdot, thetadot'],...
		'position',[245,220,275,260])

add_block('built-in/Inport',[sys,'/','display/in_1'])
set_param([sys,'/','display/in_1'],...
		'Port','2',...
		'position',[30,195,50,215])

add_block('built-in/Note',[sys,'/',['display/Display of signals: for each figure, convention is',13,'yellow -, green --, blue -. ']])
set_param([sys,'/',['display/Display of signals: for each figure, convention is',13,'yellow -, green --, blue -. ']],...
		'position',[300,375,305,380])
add_line([sys,'/','display'],[180,240;240,240])
add_line([sys,'/','display'],[110,265;145,260])
add_line([sys,'/','display'],[110,240;145,240])
add_line([sys,'/','display'],[110,215;145,220])
add_line([sys,'/','display'],[180,165;205,165])
add_line([sys,'/','display'],[110,190;120,190;120,185;145,185])
add_line([sys,'/','display'],[110,165;145,165])
add_line([sys,'/','display'],[55,205;65,205])
add_line([sys,'/','display'],[55,330;110,330])
add_line([sys,'/','display'],[330,60;375,60])
add_line([sys,'/','display'],[65,60;90,60])
add_line([sys,'/','display'],[135,35;290,35])
add_line([sys,'/','display'],[135,60;145,60])
add_line([sys,'/','display'],[230,60;290,60])
add_line([sys,'/','display'],[280,85;290,85])
add_line([sys,'/','display'],[135,85;195,85])


%     Finished composite block 'display'.

set_param([sys,'/','display'],...
		'position',[625,36,665,294])

add_block('built-in/Note',[sys,'/',['Display of signals: for each figure, convention is',13,'yellow -, green --, blue -. ']])
set_param([sys,'/',['Display of signals: for each figure, convention is',13,'yellow -, green --, blue -. ']],...
		'position',[725,310,730,315])
add_line(sys,[545,150;555,150;555,225;255,225;255,140;280,140])
add_line(sys,[425,150;460,150])
add_line(sys,[355,70;370,70;370,145;395,145])
add_line(sys,[205,250;235,250;235,165;280,165])
add_line(sys,[80,70;315,70])
add_line(sys,[180,90;225,90;225,80;315,80])
add_line(sys,[160,45;230,45;230,60;315,60])
add_line(sys,[135,195;160,195])
add_line(sys,[85,230;160,230])
add_line(sys,[120,265;160,265])
add_line(sys,[55,300;160,300])
add_line(sys,[85,335;160,335])
add_line(sys,[100,135;115,135;115,160;160,160])
add_line(sys,[235,250;620,250])
add_line(sys,[320,155;395,155])
add_line(sys,[440,150;440,80;620,80])
add_line(sys,[555,165;620,165])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
