function [ret,x0,str,ts,xts]=fansurf(t,x,u,flag);
%FANSURF	is the M-file description of the SIMULINK system named FANSURF.
%	The block-diagram can be displayed by typing: FANSURF.
%
%	SYS=FANSURF(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes FANSURF to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling FANSURF with a FLAG of zero:
%	[SIZES]=FANSURF([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[100,100,600,400])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[80,83,110,117])

add_block('built-in/Inport',[sys,'/','in_1'])
set_param([sys,'/','in_1'],...
		'hide name',0,...
		'position',[25,70,45,90])

add_block('built-in/Inport',[sys,'/','in_2'])
set_param([sys,'/','in_2'],...
		'hide name',0,...
		'Port','2',...
		'position',[25,90,45,110])

add_block('built-in/Inport',[sys,'/','in_3'])
set_param([sys,'/','in_3'],...
		'hide name',0,...
		'Port','3',...
		'position',[25,110,45,130])

add_block('built-in/S-Function',[sys,'/','Ducted Fan'])
set_param([sys,'/','Ducted Fan'],...
		'function name','fanrhs',...
		'position',[195,105,270,125])


%     Subsystem  'Surface Allocation'.

new_system([sys,'/','Surface Allocation'])
set_param([sys,'/','Surface Allocation'],'Location',[431,456,718,604])
open_system([sys,'/','Surface Allocation'])

add_block('built-in/Inport',[sys,'/','Surface Allocation/x'])
set_param([sys,'/','Surface Allocation/x'],...
		'Port','2',...
		'position',[15,60,35,80])

add_block('built-in/Outport',[sys,'/','Surface Allocation/out_1'])
set_param([sys,'/','Surface Allocation/out_1'],...
		'hide name',0,...
		'position',[210,55,230,75])

add_block('built-in/Inport',[sys,'/','Surface Allocation/u'])
set_param([sys,'/','Surface Allocation/u'],...
		'move name',0,...
		'position',[15,45,35,65])

add_block('built-in/Mux',[sys,'/','Surface Allocation/Mux'])
set_param([sys,'/','Surface Allocation/Mux'],...
		'hide name',0,...
		'inputs','[3 6]',...
		'position',[50,46,80,79])

add_block('built-in/S-Function',[sys,'/','Surface Allocation/Surface Allocation'])
set_param([sys,'/','Surface Allocation/Surface Allocation'],...
		'function name','surfalloc',...
		'position',[125,55,185,75])
add_line([sys,'/','Surface Allocation'],[40,70;45,70])
add_line([sys,'/','Surface Allocation'],[190,65;205,65])
add_line([sys,'/','Surface Allocation'],[40,55;45,55])
add_line([sys,'/','Surface Allocation'],[85,65;120,65])


%     Finished composite block 'Surface Allocation'.

set_param([sys,'/','Surface Allocation'],...
		'position',[140,87,170,138])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'hide name',0,...
		'outputs','6',...
		'position',[300,56,335,174])

add_block('built-in/Outport',[sys,'/','state4'])
set_param([sys,'/','state4'],...
		'hide name',0,...
		'move name',0,...
		'Port','5',...
		'position',[380,135,400,155])

add_block('built-in/Outport',[sys,'/','state3'])
set_param([sys,'/','state3'],...
		'hide name',0,...
		'move name',0,...
		'Port','4',...
		'position',[380,115,400,135])

add_block('built-in/Outport',[sys,'/','state2'])
set_param([sys,'/','state2'],...
		'hide name',0,...
		'move name',0,...
		'Port','3',...
		'position',[380,95,400,115])

add_block('built-in/Outport',[sys,'/','state1'])
set_param([sys,'/','state1'],...
		'hide name',0,...
		'move name',0,...
		'Port','2',...
		'position',[380,75,400,95])

add_block('built-in/Outport',[sys,'/','state'])
set_param([sys,'/','state'],...
		'hide name',0,...
		'move name',0,...
		'position',[380,55,400,75])

add_block('built-in/Outport',[sys,'/','state5'])
set_param([sys,'/','state5'],...
		'hide name',0,...
		'move name',0,...
		'Port','6',...
		'position',[380,155,400,175])
add_line(sys,[175,115;190,115])
add_line(sys,[275,115;280,115;280,155;115,155;115,125;135,125])
add_line(sys,[115,100;135,100])
add_line(sys,[50,80;55,80;55,90;75,90])
add_line(sys,[50,100;75,100])
add_line(sys,[50,120;55,120;55,110;75,110])
add_line(sys,[275,115;295,115])
add_line(sys,[340,145;375,145])
add_line(sys,[340,125;375,125])
add_line(sys,[340,105;375,105])
add_line(sys,[340,85;375,85])
add_line(sys,[340,65;375,65])
add_line(sys,[340,165;375,165])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
