% forward.m - script to generate a simple forward trajectory
%
% RMM, 14 May 96
%
% This script generates 'forward.trj', a trajectory file containing
% a forward motion at 6 m/s.  It uses the trim information from
% Sudipto's program to figure out the proper pitch value.

%
% User defined variables
%
TrimTable = '/home/dfan/lib/milam-may96/trim_positive.lut';
Speed = 6;	% desired speed in m/s

%
% Initialization
%
% Add Falcon interface routines to our path
P = path;
path(P, '/home/murray/src/falcon1.0/matlab');

% Open up the lookup table for the trim data
S = lu_load(TrimTable);

% Compute the elevator angle and angle of attack for this wind speed
data = lu_lookup(S, [Speed]);
alpha = data(1)*pi/180; 		%% deg2rad
elevator = data(2)*pi/180;
thrust = 0.4; 				%% Newton

%%% FB
alpha = .23;
thrust= .8;
elevator = 0;

% Now generate a constant velocity trajectory
%
time = (0:10:100)';
len = length(time);

% Desired position
x = time * Speed;
z = zeros(len, 1);
th = alpha * ones(len, 1);

% Designed velocity
xdot = Speed * ones(len, 1);
zdot = zeros(len, 1);
thdot = zeros(len, 1);

% Required for inputs
Fxbody = thrust*ones(len, 1);
Fzbody = zeros(len, 1);
delta_e = elevator * ones(len, 1);

%
% Write the trajctory to a file
%

namefile = 'forward.trj';
dfanlib = '/home/dfan/lib/milam-may96/';
traj_write_matrix([dfanlib namefile], time, [Fxbody Fzbody delta_e x z th xdot zdot thdot]);
