%% initsurf.m
%initialization file for demosurf.m
%define various constants for Milam fan simulation
%
%dstate = fansurf(time, state, input, FLAG)
%
%MvN 3/24/96, FB 13/6/96

disp(' initsurf.m');
disp(' + define some variables');

% useful params
rad2deg = 180/pi; RAD2DEG = 180/pi;
deg2rad = pi/180; DEG2RAD = pi/180;
FLAG = 1;
time = 0;

% various others
mx = 4.9; 
mz = 8.36; 
mg = 0.46; 
Jtheta = 0.0323; 
grav = 9.8066;   
Fzoffset = grav*mg; 
r = 0.12; 				% dist(c.m., point where forces attach) [m]
Ts = 0.005; 				% 200 Hz


%%%% define trim conditions:
xdot    = 6; 				%% m/s
theta   = .23; 				%% rad
delta_e = 0; 				%% rad

Fxbody  = (.8); 				%% Newton
Fzbody  = 0; 				%% Newton

%% (( a good set was [8m/s, 7deg, 1.825volt, -1.5delta_e,0] ))
%% Now, define x(t)=xdot*t
T=(0:.1:25)';
Xtime=(xdot*T); 			%% meters per second

%%% set up nominal state of milamfan
state = [0 0 theta xdot 0 0]; 		%% state=[x,y,theta,xdot,ydot,thetadot]
input = [Fxbody Fzbody delta_e]; 	%% inputs=[Fxbody,Fzbody,delta_e]

% let's run milamfun once, to initialize the cmex file
% and to show how to call it:
dstate = fansurf(time, state, input, FLAG)

% note that "dstate" is not zero.
% that is, i.e. "state" is not a nicely trimmed out condition.

% compute the linearization with linmod
% note c=eye and d=zero
[Afs Bfs Cfs Dfs] = linmod('fansurf', state, input);

% simple static lqr controller.
Q = diag([.01 2 10 .01 1 5]);
R = [1 0 0; 0 7 0; 0 0 5];

K = lqr(Afs,Bfs,Q,R);

%%% all the zeros are required to fit the [Ac, Bc, Cc, Dc]
%%% structure required in the simulink block "controller".
Ac = -1;
Bc = [0,0,0,0,0,0,0,0,0,0,0,0];
Cc = [0; 0; 0];

%% here we actually plug in the controller:
%% two copies of K mean (x-xd)
Dc = [-K K];


%% done


